#!/bin/sh
set -e
# Automatically added by dh_installinit
if [ -x "/etc/init.d/benno-smtp" ]; then
	update-rc.d benno-smtp defaults >/dev/null
	invoke-rc.d benno-smtp start || exit $?
fi
# End automatically added section
